==> cxf-systests-ws-security-2.4.3-fuse-01-02-sources.jar: org/example/schema/doubleit/ObjectFactory.java <==

package org.example.schema.doubleit;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.example.schema.doubleit package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _DoubleItHeader_QNAME = new QName("http://www.example.org/schema/DoubleIt", "DoubleItHeader");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.example.schema.doubleit
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DoubleItResponse }
     * 
     */
    public DoubleItResponse createDoubleItResponse() {
        return new DoubleItResponse();
    }

    /**
     * Create an instance of {@link DoubleIt }
     * 
     */
    public DoubleIt createDoubleIt() {
        return new DoubleIt();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Integer }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.example.org/schema/DoubleIt", name = "DoubleItHeader")
    public JAXBElement<Integer> createDoubleItHeader(Integer value) {
        return new JAXBElement<Integer>(_DoubleItHeader_QNAME, Integer.class, null, value);
    }

}

==> cxf-systests-ws-security-2.6.0.fuse-71-047-sources.jar: org/example/schema/doubleit/ObjectFactory.java <==

package org.example.schema.doubleit;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the org.example.schema.doubleit package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _DoubleItHeader_QNAME = new QName("http://www.example.org/schema/DoubleIt", "DoubleItHeader");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: org.example.schema.doubleit
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link DoubleItFault }
     * 
     */
    public DoubleItFault createDoubleItFault() {
        return new DoubleItFault();
    }

    /**
     * Create an instance of {@link DoubleItResponse }
     * 
     */
    public DoubleItResponse createDoubleItResponse() {
        return new DoubleItResponse();
    }

    /**
     * Create an instance of {@link DoubleIt }
     * 
     */
    public DoubleIt createDoubleIt() {
        return new DoubleIt();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link Integer }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://www.example.org/schema/DoubleIt", name = "DoubleItHeader")
    public JAXBElement<Integer> createDoubleItHeader(Integer value) {
        return new JAXBElement<Integer>(_DoubleItHeader_QNAME, Integer.class, null, value);
    }

}
